[![Codacy Badge](https://api.codacy.com/project/badge/Grade/3d0ca33bc82d4af4995ba2eab33cd102)](https://app.codacy.com/manual/mojikimino/mkn?utm_source=github.com&utm_medium=referral&utm_content=mojikimino/mkn&utm_campaign=Badge_Grade_Dashboard)
[![Build Status](https://travis-ci.com/mojikimino/mkn.svg?branch=master)](https://travis-ci.com/mojikimino/mkn)
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fmojikimino%2Fmkn.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Fmojikimino%2Fmkn?ref=badge_shield)
[![PyPI](https://img.shields.io/pypi/wheel/mkn?style=flat-square)](https://img.shields.io/pypi/wheel/mkn?style=flat-square)


# A minimum PyPI project

```
$ pip install mkn
```

# Usage

To have a check pip works well, run the following command.

```python
from mkn import sample
sample.work_well()
>>> "ok"
```


## License
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fmojikimino%2Fmkn.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fmojikimino%2Fmkn?ref=badge_large)
